===========
Change logs
===========

v0.1.1
======

:Date: 2024-09-24 (JST)

Others
------

* Add link to document on PyPI.

v0.1.0
======

:Date: 2024-09-16 (JST)

First release.

Features
--------

* Define ``audio`` directive and role.
